@@ -37,9 +37,6 @@ class AzureMLLunaUtils(BaseLunaUtils):
                         'subscriptionId':self._args.subscriptionId,
                         'modelId': self._args.modelId})
 
-    def GetModelPath(self, context):
-        return os.getenv('AZUREML_MODEL_DIR')
-
     def GetDeploymentConfig(self, tags):
         with open(self._luna_config['azureml']['workspace_config']) as file:
             documents = yaml.full_load(file)
